% Program for WT compression
%
% Output:
%    figure 5.2(a) and (b)
%    figure 5.3(a) and (b)
%    RMS between original and reconstructed signal.
%
    clear;
%
% Generate original data - figure 5.2(a)
%
   params = [3 4 0.5; ...
             10 5.5 0.5; ...
             5 7 0.6; ...
             2 8.5 0.6; ...
             7 10 0.7; ...
             9 12 0.7; ...
             1 14 0.8; ...
             3 16 0.8];
    x = 0.005:20/1024:20;
    y = mgauss(x,params);
%   
% make wavelet filter
%
    qmf = makeonfilter('Daubechies',18);
%    
% set resolution level, J = dyadlength(y) - J0
%
    J0 = 6;
%    
% perform forward WT
%
    wc = fwt_po(y,J0,qmf);
%    
% hard thresholding
%
    w = reverse((sort(wc.^2)));
    wct = keepbiggest(wc,128);
%    
% perform inverse WT
%
    comp = iwt_po(wct,J0,qmf);
%
% display figure 5.2(a) and 5.2(b)   
%
    figure; hold on;
    plot(x,y);
    plot(x,comp + 2,'r');
%
% display figure 5.3(a) and 5.3(b)
%
    figure; hold on;
    plot(wc);
    plot(sqrt(w),'r');
%
% display RMS
%
    disp(rms(y - comp));
%
% end of program
%
