% Program for WPT compression
%
% Output:
%    figure 5.6(a) and (b)
%    figure 5.7(a) and (b)
%    RMS between original and reconstructed signal.
%
    clear;
%
% Generate original data
%
   params = [3 4 0.5; ...
             10 5.5 0.5; ...
             5 7 0.6; ...
             2 8.5 0.6; ...
             7 10 0.7; ...
             9 12 0.7; ...
             1 14 0.8; ...
             3 16 0.8];
    x=0.005:20/1024:20;
    y = mgauss(x,params);
%    
% set resolution level
%
    J=9;
%    
% make wavelet filter
%
    qmf = makeonfilter('Daubechies',18);
%
% perform WPT & find best-basis
%
    wp = wpanalysis(y,J,qmf);
    st = calcstattree(wp,'Entropy');
    [bb,vt] = bestbasis(st,J);
%
% plot best-basis
%
    figure; plotbasi(bb,J,st);
%
% Apply thresholding
%
    dirtycoef = unpackbasiscoeff(bb,wp);
    compcoef = keepbiggest(dirtycoef,128);
%
% Perform inverse WPT
%
    compwp = packbasiscoeff(bb,wp,compcoef);
	 comp   = wpsynthesis(bb,compwp,qmf);      
%
% display figure 5.6(a) and (b)
%
    figure; hold on;
    plot(x,y); 
    plot(x,comp+2,'r');
%
% display figure 5.7(a) and (b)
%
    wdcoef = reverse((sort(dirtycoef.^2)));
    wdcoef = sqrt(wdcoef);
    figure; hold on;
    plot(dirtycoef);
    plot(wdcoef,'r');
%
% display RMS
%
    disp(rms(y-comp));
%
% end of program
%
