% Program for WPT compression of a NMR signal
%
% Input:
%    bionmr.dat, Figure 5.8
%
% Output:
%    figure 5.11
%    figure 5.12
%    RMS between original and reconstructed signal.
%
    clear;
%
% input original data
%
   load bionmr.dat;
   x=bionmr(:,1);
   y=bionmr(:,2);
%    
% set resolution level
%
   J=10;   
%    
% make wavelet filter
%
   qmf = makeonfilter('Symmlet',6);
%
% perform WPT & find best-basis
%
	wp = wpanalysis(y,J,qmf);
	st = calcstattree(wp,'Entropy');
   [bb,vt] = bestbasis(st,J);
%
% plot best-basis
%
   figure; plotbasi(bb,J,st);
%
%   Apply thresholding
%
	dirtycoef = unpackbasiscoeff(bb,wp);
   wptc1 = keepbiggest(dirtycoef,2048);
   wptc2 = keepbiggest(dirtycoef,1024);
   wptc3 = keepbiggest(dirtycoef,512);
%
% perform inverse WPT
%
   conwpt1 = packbasiscoeff(bb,wp,wptc1);
	const1  = wpsynthesis(bb,conwpt1,qmf);      
	conwpt2 = packbasiscoeff(bb,wp,wptc2);
	const2  = wpsynthesis(bb,conwpt2,qmf);      
	conwpt3 = packbasiscoeff(bb,wp,wptc3);
	const3  = wpsynthesis(bb,conwpt3,qmf);      
%
% display figure 5.11
%
   figure; hold on;
   axis([0 32768 -0.01 0.01])
   plot(dirtycoef);
%
% display figure 5.12
%
   figure; hold on;
   axis([0 10 -0.005 0.105]);
   plot(x,y);
   plot(x,const1+0.02,'r');
   plot(x,const2+0.04,'g');
   plot(x,const3+0.06,'b');
%
% display RMS
%
   disp(rms(y-const1'));
   disp(rms(y-const2'));
   disp(rms(y-const3'));
%
