% Program for WT compression of an NMR signal
%
% Input:
%    bionmr.dat, figure 5.8
%
% Output:
%    figure 5.9
%    figure 5.10
%    RMS between original and reconstructed signal.
%
    clear;
%
% input original data
%
	load bionmr.dat;
	x=bionmr(:,1);
   y=bionmr(:,2);
%   
% make wavelet filter
%
   f=makeonfilter('Symmlet',10);
%
% set resolution level J = dyadlength(y) - t
%
   t=5;
%
% perform FWT
%
   wc=fwt_po(y,t,f);
%   
% hard thresholding
%
   wct1 = keepbiggest(wc,2048);
   wct2 = keepbiggest(wc,1024);
   wct3 = keepbiggest(wc,512);
%    
% perform inverse WT
%
   const1 = iwt_po(wct1,t,f);
   const2 = iwt_po(wct2,t,f);
   const3 = iwt_po(wct3,t,f);
%
% display figure 5.9
%
   figure; hold on;
   axis([0 32768 -0.01 0.01])
   plot(wc);
%
% display figure 5.10   
%
   figure; hold on;
   axis([0 10 -0.005 0.105]);
   plot(x,y);
   plot(x,const1+0.02,'r');
   plot(x,const2+0.04,'g');
   plot(x,const3+0.06,'b');
%
% display RMS
%
   disp(rms(y-const1));
   disp(rms(y-const2));
   disp(rms(y-const3));
%
% end of program.
%