% Program for WT denoising of the simulated chromatogram
%
% Output:
%    figure 5.13
%
    clear;
%    
% Generate original data, Figure 13 (b)
%
   params = [7 2 0.7; ...
             7 4.2 0.7; ...
             7 5.2 0.7; ...
             7 7.5 0.7; ...
             3 8.5 0.7];
   x = 0.005:10/1024:10;
   y0 = mgauss(x,params);
   y0 = y0./max(y0);
   noise = rand(size(y0))-0.5;
   y0 = y0 + 0.02*noise;
   x = x(:);
   y0 = y0(:);   
%   
% make wavelet filter
%
	f=makeonfilter('Symmlet',4);
%   
% normalize the data to noise level 1
%
   y = normnoise(y0,f);
%
% set resolution level J = dyadlength(y) - J0
%
   J0=5;
%
% perform FWT
%
   wc=fwt_po(y,J0,f);
%
% hard thresholding, Figure 13 (c)
%
   w  = sqrt(reverse((sort(wc.^2))));
	i = max(find(w>((max(wc)-min(wc))*0.003)));
	thresh = w(i);
	wct = hardthre(wc,thresh);
	yyh = iwt_po(wct,J0,f);
   figure; hold on;
   axis([0 10 -5 270])
   plot(x,y); % Figure 13 (b)
   plot(x,yyh + 15,'r'); % Figure 13 (c)
%
% soft thresholding, Figure 13 (d)
%
   w  = sqrt(reverse((sort(wc.^2))));
	i = max(find(w>((max(wc)-min(wc))*0.003)));
	thresh = w(i);
	wct = softthresh(wc,thresh);
	yys = iwt_po(wct,J0,f);
	plot(x,yys + 30,'g');
%
% SURE (hard), Figuer 13 (e)
%
	[n,J]=dyadlength(wc);
	for j=J-1:-1:J0
 	  [wct(dyad(j)),thresh] = surethresh(wc(dyad(j)));
	end
   [wct(1:(2.^J0)),thresh] = surethresh(wc(1:(2.^J0)));
	yysu = iwt_po(wct,J0,f);
	plot(x,yysu + 45,'b');
%
% Hybrid (soft), Figure 13 (f)
%
   for j=J-1:-1:J0
 	  wct(dyad(j)) = hybridthresh(wc(dyad(j)));
   end
   wct(1:(2.^J0)) = hybridthresh(wc(1:(2.^J0)));
   yyhy = iwt_po(wct,J0,f);
	plot(x,yyhy + 60,'c');
%
% Visu (hard), Figure 13 (g)
%
 	wct = visuthresh(wc,'hard');
	yyvih = iwt_po(wct,J0,f);
	plot(x,yyvih + 75,'m');
%
% minmax (hard), Figure 13 (h)
%
   for j=J-1:-1:J0
 	  wct(dyad(j)) = minmaxth(wc(dyad(j)));
   end
   wct(1:(2.^J0)) = minmaxth(wc(1:(2.^J0)));
	yymm = iwt_po(wct,J0,f);
	plot(x,yymm + 90,'w');
%
% end of program
%
