% Program for WT denoising of the simulated chromatogram
%
% Output:
%    figure 5.14
%
    clear;
%    
% Generate original data
%
   params = [7 2 0.7; ...
             7 4.2 0.7; ...
             7 5.2 0.7; ...
             7 7.5 0.7; ...
             3 8.5 0.7];
   x = 0.005:10/1024:10;
   y0 = mgauss(x,params);
   y0 = y0./max(y0);
   noise = rand(size(y0))-0.5;
   y0 = y0 + 0.1*noise;
   x = x(:);
   y0 = y0(:);   
%   
% make wavelet filter
%
	f=makeonfilter('Symmlet',4);
%   
% normalize the data to noise level 1
%
   y = normnoise(y0,f);
%
% set resolution level J = 10 - J0
%
   J0=5;
%
% perform FWT
%
   wc=fwt_po(y,J0,f);
%
% hard thresholding
%
   w  = sqrt(reverse((sort(wc.^2))));
	i = max(find(w>((max(wc)-min(wc))*0.015)));
	thresh = w(i);
	wct = hardthre(wc,thresh);
	yyh = iwt_po(wct,J0,f);
   figure; hold on;
   axis([0 10 -2 66])
   plot(x,y); plot(x,yyh + 5,'r');
%
% soft thresholding
%
   w  = sqrt(reverse((sort(wc.^2))));
	i = max(find(w>((max(wc)-min(wc))*0.015)));
	thresh = w(i);
	wct = softthresh(wc,thresh);
	yys = iwt_po(wct,J0,f);
	plot(x,yys + 10,'g');
%
% SURE (hard)
%
	[n,J]=dyadlength(wc);
	for j=J-1:-1:J0
 	  [wct(dyad(j)),thresh] = surethresh(wc(dyad(j)));
	end
   [wct(1:(2.^J0)),thresh] = surethresh(wc(1:(2.^J0)));
	yysu = iwt_po(wct,J0,f);
	plot(x,yysu + 15,'b');
%
% Hybrid (soft)
%
   for j=J-1:-1:J0
 	  wct(dyad(j)) = hybridthresh(wc(dyad(j)));
   end
   wct(1:(2.^J0)) = hybridthresh(wc(1:(2.^J0)));
   yyhy = iwt_po(wct,J0,f);
	plot(x,yyhy + 20,'c');
%
% Visu (hard)
%
 	wct = visuthresh(wc,'hard');
	yyvih = iwt_po(wct,J0,f);
	plot(x,yyvih + 25,'m');
%
% minmax (hard)
%
   for j=J-1:-1:J0
 	  wct(dyad(j)) = minmaxth(wc(dyad(j)));
   end
   wct(1:(2.^J0)) = minmaxth(wc(1:(2.^J0)));
	yymm = iwt_po(wct,J0,f);
	plot(x,yymm + 30,'w');
%
% end of program
%
