% Program for WT smoothing of the simulated chromatogram
%
% Output:
%    figure 5.15
%    figure 5.16
%
   clear;
%    
% Generate original data, Figure 5.14 (b), SNR = 20
%
   params = [7 2 0.7; ...
             7 4.2 0.7; ...
             7 5.2 0.7; ...
             7 7.5 0.7; ...
             3 8.5 0.7];
   x = 0.005:10/1024:10;
   yc = mgauss(x,params);
   yc = yc./max(yc);
   noise = rand(size(yc))-0.5;
   y = yc + 0.1*noise;
   x = x(:)';
   y = y(:)';   
%   
% make wavelet filter
%
	qmf=makeonfi('Daubechies',4);
	H=qmf;
	G=mirrorfi(H);
%   
% set resolution level J = 5
%
    J = 5;
%
% perform FWT
%
	yy=y;
	for i=1:J
	  [cc(i,:),dd(i,:)]=dvi22(yy,H,G);
	  H=upsample(H);
	  G=upsample(G);
	  yy=cc(i,:);
 	end
%
% display figure 5.15
%
   figure;
   subplot(1,2,1); hold on;
   axis([1 1024 -0.2 5]);
   for i=1:J, plot(cc(i,:) + (i-1)); end
   subplot(1,2,2); hold on;
   axis([1 1024 -0.2 5]);
   for i=1:J, plot(dd(i,:) + (i-1)); end
%
% perform smoothing
%
   ccc=cc(J,:);
	for i=J:-1:1
	  H=down(H); 
     G=down(G); 
     if i>4 ddd=dd(i,:);
     else ddd=zeros(size(dd(i,:)));
     end
	  ccc=confrom2(ccc,ddd,H,G);
	end
%
% display figure 5.16
%
   figure; hold on;
   axis([1 1024 -0.1 1.25]);
   plot(yc);
   plot(ccc+0.2,'r');
%
% dispaly RMS
%
   disp(rms(ccc-y));
%
% end of program
%