% Program for WPT denoising
%
% Output:
%    figure 5.19(a)
%
   clear;
%    
% Generate original data, Figure 5.14 (b)
%
   params = [7 2 0.7; ...
             7 4.2 0.7; ...
             7 5.2 0.7; ...
             7 7.5 0.7; ...
             3 8.5 0.7];
   x = 0.005:10/1024:10;
   y = mgauss(x,params);
   y = y./max(y);
   noise = rand(size(y))-0.5;
   y = y + 0.1*noise;
   x = x(:);
   y = y(:);   
%   
% make wavelet filter
%
	qmf = makeonfilter('Symmlet',4);
%   
% normalize the data to noise level 1
%
   [y0,k] = nmnoise(y,qmf);
%   
% set resolution level J = log10(n)/log10(2)
%
 	[n,J] = dyadlength(y0); 
   D = log10(n)/log10(2);
%
% perform WPT & find best-basis for denoising
%
	wp = wpanalysis(y0,D,qmf);
	st = calcstattree(wp,'Entropy');
	[bb,vt] = bestbasis(st,D);
%
% apply thresholding
%
	dirtycoef = unpackbasiscoeff(bb,wp);
   thr=(max(max(wp))-min(min(wp)))*0.008;
   cleancoef = hardthresh(dirtycoef,thr);
%
% perform inverse WPT
%
	cleanwp   = packbasiscoeff(bb,wp,cleancoef);
	clean     = wpsynthesis(bb,cleanwp,qmf);      
%
% display figure 5.19(a)
%
   y1=clean./k;
   plot(x,y,x,y1,'r');
%
% end of program
%