% Program for WT baseline removal of EXAFS signal
%
% Input:
%    exafsb.dat, experimental data, Figure 5.24 (a)
%    exafsa.dat, converted k-space experiemtnal data, Figure 5.24 (b)
%
% Output:
%    figure 5.24
%    figure 5.25
%
    clear;
%
% input original data
%
   load exafsa.dat;
   x = exafsa(:,1);
   y = exafsa(:,2);
   load exafsb.dat;
   x0 = exafsb(:,1);
   y0 = exafsb(:,2);
%    
% make wavelet filter
%
   qmf = makeonfi('Daubechies',4);
	H = qmf;
	G = mirrorfi(H);
%    
% extension & cut the length to be 2.^n
%
   ky = [y reverse(y)];
   ky = ky(1:256);
%    
% set resolution level, J = dyadlength(ky) - 4
%
   t = 4;
	n = length(ky);
	yy = ky;
%    
% perform FWT
%
   wc = fwt_po(yy,t,qmf);
%
% display figure 5.25
%
   c4 = wc(1:8); d4 = wc(17:24); d3 = wc(33:48);
   d2 = wc(65:96); d1 = wc(129:192);
   figure;
   subplot(5,1,1); hold on; 
   axis([1 64 min(d1) max(d1)]); plot(d1);
   subplot(5,1,2); hold on; 
   axis([1 32 min(d2) max(d2)]); plot(d2);
   subplot(5,1,3); hold on; 
   axis([1 16 min(d3) max(d3)]); plot(d3);
   subplot(5,1,4); hold on; 
   axis([1 8 min(d4) max(d4)]); plot(d4);
   subplot(5,1,5); hold on; 
   axis([1 8 min(c4) max(c4)]); plot(c4);
%   
% perform IWT
%
   pat = 1:16;
   wct = [zeros(size(pat)) wc(17:256)];
   yyh = iwt_po(wct,t,qmf);
   yyh = yyh(1:128);
%
% display figure 5.24
%
   figure;
   subplot(3,1,1); hold on; 
   axis([min(x0) max(x0) min(y0) max(y0)]); plot(x0,y0);
   subplot(3,1,2); hold on; 
   axis([min(x) max(x)  min(y) max(y)]); plot(x,y);
   subplot(3,1,3); hold on; 
   axis([x(1) x(128) min(yyh) max(yyh)]); plot(x(1:128),yyh);
%
% end of program
%
