% Program for WT baseline removal of EXAFS signal
%
% Input:
%    exafsb.dat, experimental data, Figure 5.26 (c0)
%
% Output:
%    figure 5.26
%    figure 5.27
%
    clear;
%
% input original data
%
	load exafsb.dat;
	x1 = exafsb(:,1)';
	y1 = exafsb(:,2)';
%
% extension the data length
%
   n = length(y1);
   x = [x1 x1 x1 x1 x1];
	y = [y1 reverse(y1) y1 reverse(y1) y1];	
%
% make wavelet filter
%
   qmf = makeonfi('Daubechies',4);
   H = qmf;
	G = mirrorfi(H);
%
% set resolution level
%
	J = 5;
%
% perform FWT with the improved algorithm
%
   yy = y;
   for i = 1:J
	  [cc(i,:),dd(i,:)] = dvi22(yy,H,G);
	  H = upsample(H);
	  G = upsample(G);
     yy0 = cc(i,:);
     for l = 1:1*(2.^(i-1)-2) % shift adjustment
       yy0 = rshift(yy0);
     end
     yy = yy0;
     c(i,:) = yy0;
     d(i,:) = dd(i,:);
   end
%
% display figure 5.26
%
   cy(1,:) = c(1,2*n+1:3*n);
   cy(2,:) = c(2,2*n+1:3*n);
   cy(3,:) = c(3,2*n+1:3*n);
   cy(4,:) = c(4,2*n+1:3*n);
   figure; hold on;
   axis([min(x) max(x) -0.2 2.5]);
   plot(x1,y1);
   for i = 1:4 plot(x1, cy(i,:)+0.2*i); end
%
% subtract background
%
   yyy = y1-c(4,2*n+1:3*n);
%
% convert to k space
%
   e0 = 8983.5;
   x0 = min(find(x1>=e0));
	n = length(x1);
	ex = x1(x0:n);
	ey = yyy(x0:n);
	en = length(ex);
	mink = 3.5;
	maxk = sqrt((ex(en)-e0)*0.263);
	delta = (maxk-mink)/127;
	kx = mink:delta:maxk;
	ke = kx.*kx/0.263+e0;
%
% display figure 5.27(a)
%
	ky = spline(ex,ey,ke);
   figure; hold on;
   axis([min(kx) max(kx) -0.11 0.13]);
   plot(kx,ky);
%
% end of program
%